<template>
    <div class="system-gas-container">
        <el-card shadow="hover">
            <div class="system-menu-search mb15">
                <el-form :inline="true" style="display: flex;align-items: flex-start;flex-wrap: wrap" >
                    <el-form-item label="日期：" >
                        <el-date-picker
                            v-model="state.tableData.listQuery.searchParams.time"
                            type="datetimerange"
                            format="YYYY-MM-DD HH:mm:ss"
                            range-separator="~"
                            start-placeholder="开始时间"
                            end-placeholder="结束时间"
                            @change = "chooseTime"
                        />
                    </el-form-item>
                    <el-form-item label="气象类型：">
                        <el-select
                            v-model="state.tableData.listQuery.searchParams.weatherType"
                            class="w100"
                            style="max-width: 180px"
                            size="default"
                        >
                            <el-option v-for="item in state.tableData.weatherTypeList" :key="item.label" :label="item.value" :value="item.label"></el-option>
                        </el-select>
                    </el-form-item>
                    <el-button size="default" type="primary" class="ml10" @click="search()">
                        <el-icon>
                            <ele-Search />
                        </el-icon>
                        查询
                    </el-button>
                    <el-button size="default" class="ml10" @click="reset()">
                        <el-icon>
                            <RefreshLeft />
                        </el-icon>
                        重置
                    </el-button>
                </el-form>
            </div>
            <div id="gasChart" style="height: 500px;width: auto"></div>
            <el-table :data="state.tableData.data" style="width: 100%;margin-top: 20px">
                <el-table-column type="index" label="序号" width="80" />
                <el-table-column align="center" prop="time" label="采集时间"/>
                <el-table-column align="center" prop="value" :label='weatherName' />
            </el-table>
            <br />
            <el-pagination
                @size-change="onHandleSizeChange"
                @current-change="onHandleCurrentChange"
                class="page-position"
                :pager-count="5"
                :page-sizes="[10, 20, 30]"
                v-model:current-page="state.tableData.listQuery.pageIndex"
                background
                v-model:page-size="state.tableData.listQuery.pageSize"
                layout="total, sizes, prev, pager, next, jumper"
                :total="state.tableData.total">
            </el-pagination>
            <br />
            <br />
        </el-card>
    </div>
</template>

<script setup lang="ts">
import {reactive, ref, onMounted, shallowRef} from "vue";
import * as echarts from "echarts";
import { ElMessage, ElMessageBox } from 'element-plus'
import {TableWeatherState} from "/@/types/monitorData";
import moment from "moment/moment";
import {weatherDataApi } from "/@/api/monitorData/weatherData";

const state = reactive<TableWeatherState>({
    tableData: {
        data: [],
        total: 0,
        loading: false,
        listQuery: {
            pageIndex: 1,
            pageSize: 10,
            searchParams:{
                time: [],
                weatherType: 'temp'
            }
        },
        weatherTypeList: [
            {
                label: 'temp',
                value: '温度'
            },
            {
                label: 'humidity',
                value: '湿度'
            },
            {
                label: 'windDirection',
                value: '风向'
            },
            {
                label: 'windSpeed',
                value: '风速'
            },
            {
                label: 'pressure',
                value: '压力'
            }
        ]
    }
});
const weatherName = ref('温度');
const dataZoomEnd = ref();
const xData = ref([]);
const yData = ref([]);
const myChart = shallowRef(null)

const chooseTime = (val: any) => {
    console.log("val",val)
    let sTime = Date.parse(new Date(val[0]));
    let eTime = Date.parse(new Date(val[1]));
    const datadiff = eTime - sTime + 86400000;
    const time = 7 * 24 * 60 * 60 * 1000;
    if (sTime > eTime) {
        return false;
    } else {
        if (datadiff > time) {
            ElMessage({
                type: 'error',
                message: '查询时间范围7天内',
            })
            getNowTime();
            return false;
        } else {
            console.log('七天内数据')
        }
    }
}

onMounted(
    () => {
        getNowTime();
        initInfoData();
        initCharts();

    }
);
const getNowTime = () => {
    let isDate = new Date()
    let sTime = `${isDate.getFullYear()}-${isDate.getMonth() + 1}-${isDate.getDate()}`
    let eTime = `${isDate.getFullYear()}-${isDate.getMonth() + 1}-${isDate.getDate()}`
    sTime = `${sTime} 00:00:00`
    eTime = `${eTime} ` + moment().format('HH:mm:ss')
    state.tableData.listQuery.searchParams.time = [sTime ,eTime];
}
const initInfoData = async () => {
    //折线图
    const chartParam = {
        startTime: moment(state.tableData.listQuery.searchParams.time[0]).format('YYYY-MM-DD HH:mm:ss'),
        endTime: moment(state.tableData.listQuery.searchParams.time[1]).format('YYYY-MM-DD HH:mm:ss'),
        atmosphere: state.tableData.listQuery.searchParams.weatherType
    }
    let resChart = await weatherDataApi().getWeatherLineChart(chartParam);
    if(resChart.data.code == 100) {
        xData.value = resChart.data.data.map((item: any) => {
            return item.time;
        })
        yData.value = resChart.data.data.map((item: any) => {
            return item.value;
        })
        dataZoomEnd.value = xData.value.length > 25 ? 5 : 100;
        initCharts();
    }else {
        ElMessage({
            type: 'warning',
            message: resChart.data.msg
        });
    }

    //表格
    const pageParam = {
        pageIndex: state.tableData.listQuery.pageIndex,
        pageSize: state.tableData.listQuery.pageSize,
        searchParams: {
            startTime: moment(state.tableData.listQuery.searchParams.time[0]).format('YYYY-MM-DD HH:mm:ss'),
            endTime: moment(state.tableData.listQuery.searchParams.time[1]).format('YYYY-MM-DD HH:mm:ss'),
            atmosphere: state.tableData.listQuery.searchParams.weatherType
        }
    }
    let res = await weatherDataApi().getWeatherLinePage(pageParam);
    if(res.data.code == 100) {
        state.tableData.data = res.data.data;
        state.tableData.total = res.data.total;
        state.tableData.listQuery.pageIndex = res.data.pageIndex;
        state.tableData.listQuery.pageSize = res.data.pageSize;
    }else {
        ElMessage({
            type: 'warning',
            message: res.data.msg
        });
    }
};

const changeWeather = (val: any) => {
    console.log("vall",val)
    let chooseObj = state.tableData.weatherTypeList.find(item => item.label === val);
    weatherName.value = chooseObj.value;
}
const onHandleSizeChange = (val: number) => {
    state.tableData.listQuery.pageSize = val;
    initInfoData();
};
// 分页改变
const onHandleCurrentChange = (val: number) => {
    state.tableData.listQuery.pageIndex = val;
    initInfoData();
};

const search = () => {
    console.log("vla",state.tableData.listQuery.searchParams)
    changeWeather(state.tableData.listQuery.searchParams.weatherType);
    initInfoData();
}
const reset = () => {
    getNowTime();
    state.tableData.listQuery.searchParams.weatherType = state.tableData.weatherTypeList[0].label;
    weatherName.value = "温度";
    state.tableData.listQuery.pageIndex = 1;
    initInfoData();
}

const initCharts = () => {
    if (myChart.value != null && myChart.value != "" && myChart.value != undefined) {
        myChart.value.dispose();
    }
    myChart.value = echarts.init(document.getElementById('gasChart'));
    // 指定图表的配置项和数据
    const option = {
        tooltip: {
            trigger: "axis",
            axisPointer: {
                type: 'shadow'
            },
        },
        xAxis: {
            show: true,
            type: 'category',
            data: xData.value
        },
        yAxis: {
            show: true,
            type: 'value'
        },
        series: [
            {
                data: yData.value,
                type: 'line',
            }
        ],
        dataZoom: [
            {
                type: 'slider',
                show: dataZoomEnd.value == 100 ? false : true,
                realtime: true,
                start: 0,
                end: dataZoomEnd.value
            },
            {
                type: 'inside',
                realtime: true,
                start: 0,
                end: dataZoomEnd.value
            },
        ]
    };
    // 使用刚指定的配置项和数据显示图表。
    myChart.value.setOption(option,true);
    //自适应宽度
    window.addEventListener('resize', function () {
        myChart.value.resize();
    })
}
</script>
<style scoped lang="scss">
.yellow{
    width: 80px;
    height: 30px;
    background-color: rgb(255,223,37);
    line-height: 30px;
    color: white;
    box-shadow: 4px 4px 4px rgba(0, 0, 0, 0.2);
    padding: 3px
}
.red{
    width: 80px;
    height: 30px;
    background-color: rgb(239,90,161);
    line-height: 30px;
    color: white;
    box-shadow: 4px 4px 4px rgba(0, 0, 0, 0.2);
    padding: 3px
}
</style>
